import { 
  select, 
  csv, 
  scaleLinear, 
  extent, 
  axisLeft, 
  axisBottom,
  scaleTime,
  line,
  curveBasis
} from 'd3';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

const render = data => {
  const title = 'Projected Years for SSN'
  
  const xValue = d => d.report_year;
  const xAxisLabel = 'Report Year';
  
  const yValue = d => d.delivery_date;
  const circleRadius = 6;
  const yAxisLabel = 'Projected Delivery';
  
  const margin = { top: 60, right: 40, bottom: 88, left: 150 };
  const innerWidth = width - margin.right - margin.left;
  const innerHeight = height - margin.top - margin.bottom;
  
  const xScale = scaleTime()
  	.domain(extent(data, xValue))
    .range([0, innerWidth])
  	.nice();
  
  const yScale = scaleTime()
  	.domain(extent(data, yValue))
  	.range([innerHeight, 0])
  	.nice();
  
  const g = svg.append('g')
  	.attr('transform', `translate(${margin.left},${margin.top})`)
  
  const xAxis = axisBottom(xScale)
  	.tickSize(-innerHeight)
  	.tickPadding(15);
  
  const yAxis = axisLeft(yScale)
  	.tickSize(-innerWidth)
  	.tickPadding(0);
  
  const yAxisG = g.append('g').call(yAxis);  	
  yAxisG.select('.domain').remove();
  
  yAxisG.append('text')
  	.attr('class', 'axis-label')
  	.attr('y', -85)
  	.attr('x', -innerHeight/2)
  	.attr('fill', 'black')
  	.attr('transform', 'rotate(270)')
  	.attr('text-anchor', 'middle')
  	.text(yAxisLabel);
  
  const xAxisG = g.append('g').call(xAxis)
  	.attr('transform', `translate(0, ${innerHeight} )`);
  
  xAxisG.select('.domain').remove();
  
  xAxisG.append('text')
  	.attr('class', 'axis-label')
  	.attr('y', 80)
  	.attr('x', innerWidth/2)
  	.attr('fill', 'black')
  	.text(xAxisLabel);
  
  const lineGenerator = line()
  	.x(d => xScale(xValue(d)))
  	.y(d => yScale(yValue(d)))
  	.curve(curveBasis);
  
  
  
  
  g.append('path')
  	.attr('class', 'line-path')
  	.attr('d', lineGenerator(data));
    
  g.append('text')
  .attr('class', 'title')
  .attr('y', -10)
  .text(title);
};

csv('https://vizhub.com/seanisyakov/datasets/development_data_ssn_projections.csv')
  .then(data => {
  	console.log(data);
    data.forEach(d => {  
      d.production_ssn = d.production_ssn;
      d.report_year = new Date(d.report_year);
      d.contract_award_date = new Date(d.contract_award_date);
      d.award_date_months = +d.award_date_months;
      d.delivery_date = new Date(d.delivery_date);
    })
    render(data);
});